==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebCheckboxDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCheckboxBaseDescriptionMetadata } from "./WebCheckboxBaseDescriptionMetadata";
import { WebCheckboxDescription } from "./WebCheckboxDescription";
/**
 * @hidden
 */
export let WebCheckboxDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCheckboxDescriptionMetadata extends Base {
        static b(a) {
            if (WebCheckboxDescriptionMetadata.a == null) {
                WebCheckboxDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCheckboxDescriptionMetadata.c(WebCheckboxDescriptionMetadata.a);
            }
            if (a.k(WebCheckboxDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebCheckboxDescriptionMetadata.a);
        }
        static c(a) {
            WebCheckboxBaseDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:Checkbox");
            a.item("__tagNameWC", "String:igc-checkbox");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Indeterminate", "Boolean");
        }
        static d(a) {
            WebCheckboxDescriptionMetadata.b(a);
            a.ad("WebCheckbox", () => new WebCheckboxDescription());
            a.ac("WebCheckbox", WebCheckboxDescriptionMetadata.a);
        }
    }
    WebCheckboxDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCheckboxDescriptionMetadata, 'WebCheckboxDescriptionMetadata');
    WebCheckboxDescriptionMetadata.a = null;
    return WebCheckboxDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebCheckboxDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCheckboxBaseDescriptionMetadata } from "./WebCheckboxBaseDescriptionMetadata";
import { WebCheckboxDescription } from "./WebCheckboxDescription";
/**
 * @hidden
 */
export let WebCheckboxDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCheckboxDescriptionMetadata extends Base {
        static b(a) {
            if (WebCheckboxDescriptionMetadata.a == null) {
                WebCheckboxDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCheckboxDescriptionMetadata.c(WebCheckboxDescriptionMetadata.a);
            }
            if (a.k(WebCheckboxDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebCheckboxDescriptionMetadata.a);
        }
        static c(a) {
            WebCheckboxBaseDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:Checkbox");
            a.item("__tagNameWC", "String:igc-checkbox");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Indeterminate", "Boolean");
        }
        static d(a) {
            WebCheckboxDescriptionMetadata.b(a);
            a.ae("WebCheckbox", () => new WebCheckboxDescription());
            a.ad("WebCheckbox", WebCheckboxDescriptionMetadata.a);
        }
    }
    WebCheckboxDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCheckboxDescriptionMetadata, 'WebCheckboxDescriptionMetadata');
    WebCheckboxDescriptionMetadata.a = null;
    return WebCheckboxDescriptionMetadata;
})();
